import { ProColumns } from "@ant-design/pro-table";
import { Tag } from "antd";
import React from "react";
import CancelBackPolicy from "./cancelBackPolicy";

const AccountTypeEnum = {
    OUTSIDE_APPLICATION: <Tag color="#f50">外部应用</Tag>,
    TENCENT_MINI_GAME: <Tag color="#2db7f5">腾讯小游戏</Tag>,
    OCENAENGINE_MINI_GAME: <Tag color="#87d068">头条小游戏</Tag>
}

const tableConfig = (backValueEnum: any, appObj: any) => {

    const columns: ProColumns<any>[] = [
        {
            title: '渠道名称',
            dataIndex: 'agentName',
            copyable: true,
            ellipsis: true,
            width: 220
        },
        {
            title: '渠道标识',
            dataIndex: 'agentKey',
            align: 'center',
            width: 180,
            ellipsis: true,
            copyable: true,
        },
        {
            title: '广告账号',
            dataIndex: 'accountId',
            align: 'center',
            width: 100,
            ellipsis: true
        },
        {
            title: '广告账号类型',
            dataIndex: 'accountType',
            align: 'center',
            width: 100,
            valueEnum: {
                OUTSIDE_APPLICATION: {
                    text: '外部应用'
                },
                TENCENT_MINI_GAME: {
                    text: '腾讯小游戏'
                },
                OCENAENGINE_MINI_GAME: {
                    text: '头条小游戏'
                }
            },
            render: (_, row) => {
                return AccountTypeEnum[row.accountType as keyof typeof AccountTypeEnum]
            },
        },
        {
            title: '应用',
            dataIndex: 'iaaAppId',
            align: 'center',
            width: 120,
            ellipsis: true,
            valueEnum: appObj
        },
        {
            title: '投放状态',
            dataIndex: 'putStatus',
            align: 'center',
            width: 90,
            valueEnum: {
                PUT_STATUS_PUT_STOP: {
                    text: '投放结束',
                    status: 'Success'
                },
                PUT_STATUS_PUT_ING: {
                    text: '投放中',
                    status: 'Processing',
                }
            },
        },
        {
            title: '回传策略',
            dataIndex: 'backPolicyId',
            align: 'center',
            width: 120,
            ellipsis: true,
            valueEnum: backValueEnum,
            render: (_, row) => {
                return row?.iaaAgentBackPolicyDTO?.backPolicyName || '-'
            },
        },
        {
            title: '创建人',
            dataIndex: 'createByName',
            search: false,
            align: 'center',
            width: 100
        },
        {
            title: '更新人',
            dataIndex: 'updateByName',
            search: false,
            align: 'center',
            width: 100
        },
        {
            title: '创建时间',
            key: 'showTime',
            dataIndex: 'createTime',
            valueType: 'date',
            hideInSearch: true,
            width: 140
        },
        {
            title: '创建时间',
            dataIndex: 'createTime',
            valueType: 'dateRange',
            hideInTable: true,
            search: {
                transform: (value) => {
                    return {
                        createBeginTime: value[0],
                        createEndTime: value[1],
                    };
                },
            },
        },
        {
            title: '更新时间',
            dataIndex: 'updateTime',
            search: false,
            align: 'center',
            width: 140
        },
        {
            title: '操作',
            key: 'option',
            width: 125,
            valueType: 'option',
            render: (_, row, index, action) => row?.iaaAgentBackPolicyDTO ? [
                <div key={'qx'}><CancelBackPolicy id={row.id} onChange={() => action?.reload()}/></div>
            ] : '-'
        },
    ];
    return columns
}

export default tableConfig