import { request } from 'umi';
import { api } from '../api';
let wapi = api + '/iaaData'

/**
 * 分页信息
 * @param pageNum 页码
 * @param pageSize 每页数量
 */
export interface Paging {
    pageNum: number,
    pageSize: number,
    productType?: string  // 业务类型
    appId?: string        // 应用
}


export interface SortProps {
    sortFiled?: string, // 排序字段
    sortType?: string,  // 排序方式：升序asc;降序desc
    sortAsc?: boolean   // 排序类型：升序 true;降序 false
}

/**
 * 投手列表
 * @returns 
 */
export async function getPutUserListApi() {
    return request(wapi + `/condition/putUserList`, {
        method: 'POST'
    });
}

/**
 * iaa应用 业务列表
 * @returns 
 */
export async function getAppListApi() {
    return request(wapi + `/condition/appList`, {
        method: 'POST'
    });
}

export interface GetGDTListProps extends Paging, SortProps {
    accountId?: string
    putUserIdList?: number[]   // 投手ID列表
    promotionId?: number       // 广告ID
    promotionName?: string     // 广告账名称
    status?: string            // 广告状态
    cpaBid?: number            // 当前出价
    pricing?: string           // 出价方式
    adCreateBegin?: string     // 广告创建时间
    adCreateEnd?: string
    deleted?: boolean          // 删除状态
    putDayBegin?: string       // 投放时间
    putDayEnd?: string
    costDayBegin?: string      // 消耗时间
    costDayEnd?: string
}
/**
 * 腾讯广告列表
 * @param data 
 * @returns 
 */
export async function getGDTListApi(data: GetGDTListProps) {
    return request(wapi + `/monitor/gdt/listOfPage`, {
        method: 'POST',
        data
    });
}


export interface GetGDTDailyListProps extends Paging, SortProps {
    promotionId: number,
    costDayBegin?: string,
    costDayEnd?: string
}
/**
 * 每日
 * @param data 
 * @returns 
 */
export async function getGDTDailyListApi(data: GetGDTDailyListProps) {
    return request(wapi + `/monitor/gdt/daily/detail`, {
        method: 'POST',
        data
    });
}


export async function getGDTTotalApi(data: GetGDTListProps) {
    return request(wapi + `/monitor/gdt/total`, {
        method: 'POST',
        data
    });
}



export interface GetAppTxEveryDayListProps extends Paging, SortProps {
    costDayBegin?: string
    costDayEnd?: string
}
/**
 * 应用每日数据
 * @param data 
 * @returns 
 */
export async function getAppTxEveryDayListApi(data: GetAppTxEveryDayListProps) {
    return request(wapi + `/monitor/app/gdt/listOfPage`, {
        method: 'POST',
        data
    });
}

/**
 * 应用每日数据 总计
 * @param data 
 * @returns 
 */
export async function getAppTxEveryDayTotalApi(data: GetAppTxEveryDayListProps) {
    return request(wapi + `/monitor/app/gdt/total`, {
        method: 'POST',
        data
    });
}



export interface getPutUserTxEveryDayListProps extends Paging, SortProps {
    costDayBegin?: string
    costDayEnd?: string
    putUserIdList?: number[]
}
/**
 * 投手每日数据
 * @param data 
 * @returns 
 */
export async function getPutUserTxEveryDayListApi(data: getPutUserTxEveryDayListProps) {
    return request(wapi + `/monitor/putUser/gdt/listOfPage`, {
        method: 'POST',
        data
    });
}

/**
 * 投手每日数据 总计
 * @param data 
 * @returns 
 */
export async function getPutUserTxEveryDayTotalApi(data: getPutUserTxEveryDayListProps) {
    return request(wapi + `/monitor/putUser/gdt/total`, {
        method: 'POST',
        data
    });
}